% Script to preform prediction of accuracy using the training data and
% apply the stopping rule.

% 1. We set a threshold for predicted accuracy after which to stop
% 2. We report the percentage of training data after stopping
% 3. We report the AUC value after stopping.

function [mean_percentTraining,std_percentTraining,mean_AUC,std_AUC] = ApplyStoppingRuleInCrossValidation(datasetName)

R = 20;
%load the true interaction matrix
curr_path = which('table2.m');
NrDataPath = [curr_path(1:end-17),'PrimaryData' filesep ...
    'ProteinDrugsDatabase', filesep, datasetName];
IntermediateDataPathNr = [curr_path(1:end-17),'IntermediateData', ...
    filesep, datasetName];
load([NrDataPath,'Interactions.mat'],'Interactions');
load([NrDataPath,'ProteinSimilarity.mat']);
load([NrDataPath,'DrugSimilarity.mat']);

fname = [curr_path(1:end-17),'IntermediateData\RegressionParams', ...
    filesep, 'regressionParams.mat'];

if exist(fname)
    load(fname)
else
    pathToSimulatedData = [curr_path(1:end-17),'IntermediateData', ...
        filesep, 'SimulationResults', filesep ];
    if exist(pathToSimulatedData)
        [raw_fit,bestlambda] = computeRegressionParamters(pathToSimulatedData);
    else
        mkdir(pathToSimulatedData)
        display('Generating new simulation data')
        performSimulation(pathToSimulatedData)
    end
end


%Compute the assignment for Cross Validation
numData = size(DrugSimilarity,1);
numFolds = 5;
numRepeats = 5;
D_assign = Generate_CrossvalidationDataPartition(numData,numFolds,numRepeats);
%save(['AssignmentOfDrugsForCrossValidation',datasetName(1:end-1)],'D_assign')

percentageExperiments = cell(numFolds,1);
evaluationMeasure = cell(numFolds,1);
predictedAccuracy = cell(numFolds,1);
trueAccuracy = cell(numFolds,1);

for repeat= 1:numRepeats
    for fold_idx = 1:numFolds
        IntermediateDataFile1 = [IntermediateDataPathNr,'Y_queried_for_each_run_train_R_',num2str(R),'_fold_',num2str(fold_idx),'repeat',num2str(repeat),'_drugs_holdoute.mat'];
        IntermediateDataFile2 = [IntermediateDataPathNr,'Y_likelihood_for_each_run_train_R_',num2str(R),'_fold_',num2str(fold_idx),'repeat',num2str(repeat),'_drugs_holdout.mat'];
        IntermediateDataFile3 = [IntermediateDataPathNr,'Y_test_set_fold_',num2str(fold_idx),'repeat',num2str(repeat),'_drugs_holdout.mat'];
        IntermediateDataFile4 = [IntermediateDataPathNr,'Y_likelihood_for_each_run_test_R_',num2str(R),'_fold_',num2str(fold_idx),'repeat',num2str(repeat),'_drugs_holdout.mat'];
        IntermediateDataFile5 = [IntermediateDataPathNr,'Y_train_set_fold_',num2str(fold_idx),'repeat',num2str(repeat),'_drugs_holdout.mat'];
        if(exist(IntermediateDataFile1,'file')&&exist(IntermediateDataFile2,'file')&&exist(IntermediateDataFile3,'file')&&exist(IntermediateDataFile4,'file'))
            load(IntermediateDataFile1);
            load(IntermediateDataFile2);
            load(IntermediateDataFile3);
            load(IntermediateDataFile4);
            load(IntermediateDataFile5);
        else
            ind_train = find(D_assign(repeat,:)~=fold_idx);
            display(['percent for training:',num2str(length(ind_train)/size(D_assign,2))])
            [Y_queired_all_train, Y_likelihood_all_train, Y_likelihood_all_test,Y_true_test,Y_true_train] = active_learning_KBMF_drugs_holdout_cv(Interactions, DrugSimilarity,ProteinSimilarity,R,ind_train);
            save(IntermediateDataFile1,'Y_queired_all_train');
            save(IntermediateDataFile2,'Y_likelihood_all_train');
            save(IntermediateDataFile3,'Y_true_test');
            save(IntermediateDataFile4,'Y_likelihood_all_test');
            save(IntermediateDataFile5,'Y_true_train');
        end
        percentageExperiments{fold_idx} = computePercentageCompleted_drugs(Y_queired_all_train);
        Y_predict_all_train = Y_likelihood_all_train;
        Y_predict_all_train(Y_predict_all_train>0) = 1;
        Y_predict_all_train(Y_predict_all_train<=0) = -1;
        predictedAccuracy{fold_idx} = predictAccuracy(raw_fit,bestlambda,Y_queired_all_train, Y_predict_all_train);
        trueAccuracy{fold_idx} = computeEvaluationMeasure(Y_queired_all_train,Y_predict_all_train,Y_true_train);
        %true AUC
        evaluationMeasure{fold_idx} = computeEvaluationMeasureAUCdrugs_holdout(Y_likelihood_all_test,Y_true_test);
        %figure;plot(percentageExperiments{fold_idx}(2:end),trueAccuracy{fold_idx}(2:end))
        %hold on
        %plot(percentageExperiments{fold_idx}(2:end),predictedAccuracy{fold_idx},'r')
        %legend('true','predicted')
        %hold off
    end
end
%Compute percentage of training samples and AUC after apllying a prediction
%threshold


predThreshold = 0.9;% the prediction threshold
AUC_predThreshold = zeros(1,numFolds);
percentTraining  = zeros(1,numFolds);
for fold_idx = 1:numFolds
    ind = find(predictedAccuracy{fold_idx}>=predThreshold);
    AUC_predThreshold(fold_idx) = evaluationMeasure{fold_idx}(ind(1));
    percentTraining(fold_idx) = percentageExperiments{fold_idx}(ind(1));
end
mean_percentTraining = mean(percentTraining)*0.8; % percentage out of all the data used to train (since the percentage is compute relative to the 80% of training data)
mean_AUC = mean(AUC_predThreshold);
std_AUC = std(AUC_predThreshold);
std_percentTraining = std(percentTraining)*0.8;
% display(['datasetName: ',num2str(datasetName(1:end-1))])
% display(['predThreshold: ',num2str(predThreshold)])
% display(['percent: ',num2str(mean(percentTraining)*0.8)])
% display(['mean AUC: ', num2str(mean_AUC)])
% display(['std AUC: ', num2str(std(AUC_predThreshold))])
% display(['mean percent: ',num2str(mean(percentTraining)*0.8)])
% display(['std percent: ', num2str(std(percentTraining)*0.8)])

