function [raw_fit,bestlambda] = computeRegressionParamtersOnTraining(pathToSimulatedData,numFold,Fold_assign)
%Computes the lasso regression parameters given a path to the simulated data and which data to use for training.
% The code for glmnet must be downloaded from: http://www.stanford.edu/~hastie/glmnet_matlab/
% 
% Author: Maja Temerinac-Ott
% Date: Feb 2014
% E-Mail: temerina@frias.uni-freiburg.de

path('glmnet_matlab', path)

s = what(pathToSimulatedData);
numTraining = length(find(Fold_assign~=numFold));
count = 1;
numTrace = 1;
total_feats = [];
for z = 1:numel(s.mat)
    if strcmp(s.mat{z}(1:11),'Predicted_u') 
        if(Fold_assign(numTrace)~=numFold)
        predicted = load([s.path,'\',s.mat{z}]);
        queried = load([s.path,'\','Queried' s.mat{z}(10:end)]);
        interactions = load([s.path,'\','Interactions' s.mat{z}(10:end)]);
        total_feats = [total_feats; calc_external_feats_new_maja(queried.queried, predicted.predicted, interactions.interactions)];
        end
        numTrace = numTrace+1;
    end
end

NGROUPS = size(total_feats,1)/96;

gsizes = cumsum([0 repmat(96,1,NGROUPS)]);

ppx = nchoosek(3:size(total_feats,2),2);
extended_feats = [total_feats sqrt(total_feats(:,ppx(:,1)).*total_feats(:,ppx(:,2)))];
disp('computing raw lasso fit')
raw_fit = glmnet(extended_feats(:,2:end), extended_feats(:,1)-extended_feats(:,2));
vvs = glmnetPredict(raw_fit, 'link', extended_feats(:,2:end), raw_fit.lambda(end));
%figure;plot(extended_feats(:,1)-extended_feats(:,2), abs(vvs), 'k.');xlabel('true adjusted accuracy');ylabel('predicted adjusted accuracy using lasso')
nfolds = 11;
fitty = cell(nfolds-1,2);
foldc = round(NGROUPS/nfolds);
foldsz = foldc*(nfolds-1)*96;
traind = zeros(foldsz,size(extended_feats,2));

for i = 1:(nfolds-1)
    disp(i/nfolds)
    zz = randperm(NGROUPS);
    %for j = 1:(foldc*(nfolds-1))
    for j = 1:min(length(zz),(foldc*(nfolds-1)))
       traind(((j-1)*96+1):j*96,:) = extended_feats((gsizes(zz(j))+1):(gsizes(zz(j))+96),:);
    end
    fitty{i,1} = glmnet(traind(:,2:end), traind(:,1)-traind(:,2), 'gaussian');
    fitty{i,2} = zz(foldc*(nfolds-1)+1:end);
end

lambda_space = [];
for i = 1:(nfolds-1)
    zz = log(fitty{i,1}.lambda);
    lambda_space = [lambda_space; min(zz) max(zz) mean(diff(zz))];
end

lambda_sequence = exp(linspace(min(lambda_space(:,1)), max(lambda_space(:,2)), abs(round((max(lambda_space(:,2))-min(lambda_space(:,1)))/mean(lambda_space(:,3))))));
lambda_sequence = fliplr(lambda_sequence);

fitquals = zeros(nfolds-1,length(lambda_sequence));
testd = zeros(size(extended_feats,1)-foldsz,size(extended_feats,2));
for i = 1:(nfolds-1)
    disp(i/nfolds)
    for j = 1:numel(fitty{i,2})
       testd(((j-1)*96+1):j*96,:) = extended_feats((gsizes(fitty{i,2}(j))+1):(gsizes(fitty{i,2}(j))+96),:);
    end
    deltas = abs(glmnetPredict(fitty{i,1}, 'link', testd(:,2:end), lambda_sequence'));
    fitquals(i,:) = mean((repmat(testd(:,1)-testd(:,2),1,length(lambda_sequence))-deltas).^2);
end

bestlambda = min(mean(fitquals));
