function [Y_queired_all, Y_likelihood_all,Az_all,Ax_all] = active_learning_KBMF_drugs(Interactions, DrugSimilarity,ProteinSimilarity,R,seed)
% Function to perform active learning on a protein-drugs interaction matrix.
% Active learning strategy: In each iterative run, the most uncertain one percent of drugs is selected.
%
% The parameters are the seed for the random initalization of the drug and
% the subspace dimension R, as well as an Interactions matrix (NxM), a ProteinSimilarity matrix (NxN) and a DrugSimilarity matrix (MxM).
% For example: R = 20, seed = 343
% The entries in the Interactions matrix are 0 and 1. 
%
% Author: Maja Temerinac-Ott
% Date: Feb 2014
% E-Mail: temerina@frias.uni-freiburg.de
rdata = Interactions;
rdata(Interactions==0)=-1;
true_Interactions = rdata;

%Percent of interactions per batch
%Percent of interactions per batch
percent = 0.01;
batch_size = max(1,round(percent*size(DrugSimilarity,1)));

Kx = ProteinSimilarity;
NUM_PROTEINS = size(ProteinSimilarity,1);
NUM_DRUGS = size(DrugSimilarity,1);
%Iterate through data

%Initialize the queried Labels
Y_queried = zeros(size(rdata));

%Initialize the queried Drugs
drug_assignment = ones(NUM_DRUGS,1);
%Pick random drug
rand('state', seed);
ind_rand = randsample(NUM_DRUGS,batch_size);
drug_assignment(ind_rand) = 0; %the training set has label 0


Y_queried(:,ind_rand) = true_Interactions(:,ind_rand);


% Choose 1% of interactions as batch_size
%total_runs = round(0.9*(NUM_DRUGS-batch_size)/batch_size);
total_runs = round((NUM_DRUGS-batch_size)/batch_size);
percent_of_experiments = zeros(total_runs,1) ;

Y_queired_all = zeros(size(Y_queried,1),size(Y_queried,2),total_runs);
Y_likelihood_all = zeros(size(Y_queried,1),size(Y_queried,2),total_runs);
Az_all = cell(total_runs,1);
Ax_all = zeros(NUM_PROTEINS,R,total_runs);
for num_runs = 1:total_runs
        % identify the unsampled experiments      
		ind = find(drug_assignment==1);
		% identify the training set
		ind2 = find(drug_assignment~=1);  
		train_Set_drugs = DrugSimilarity(ind2,ind2,:);
		train_Set_interactions = rdata(:,ind2);
        [Ax, Az] = computeAs( Kx, train_Set_drugs, train_Set_interactions, R);
		numb_known_drugs = NUM_DRUGS-sum(drug_assignment);
		percent_of_experiments(num_runs) = numb_known_drugs/NUM_DRUGS;
        %Pick Labels using some Active Learning Strategy
		numTest = length(ind);
		Uncertainty = zeros(1,numTest);  
        F_computed = true_Interactions;
				for i = 1:numTest
					Kz_test_single = DrugSimilarity(ind(i),ind2);
					F = Kz_test_single*Az*Ax'*ProteinSimilarity;
					F_computed(:,ind(i)) = F;
					Uncertainty(i) = sum(abs(F(:))); 
				end
		  
		[val, ind_uncertain] = sort(Uncertainty);
		%Find the most uncertain index in the remaining experiments:
		drug_assignment(ind(ind_uncertain(1:min(batch_size,length(ind_uncertain))))) = 0;
        Y_queired_all(:,:,num_runs) = Y_queried;
        Y_likelihood_all(:,:,num_runs) = F_computed;
        Az_all{num_runs}=Az;
        Ax_all(:,:,num_runs)=Ax;
        Y_queried(:,ind(ind_uncertain(1:min(batch_size,length(ind_uncertain))))) = true_Interactions(:,ind(ind_uncertain(1:min(batch_size,length(ind_uncertain)))));
        display(['Percent of drugs for training: ',num2str(numb_known_drugs/NUM_DRUGS) ]);

end

