function [Y_queired_all_train, Y_likelihood_all_train, Y_likelihood_all_test,Y_true_test,Y_true_train] = active_learning_KBMF_drugs_holdout(Interactions, DrugSimilarity,ProteinSimilarity,R,seed)
% Function to perform active learning on a training data set and use the
% results to predict the interactions on a test dataset (not used for
% training).
%
% The parameters are the seed for selecting the training set, the subspace dimension R, as well as an Interactions matrix (NxM), a ProteinSimilarity matrix (NxN) and a DrugSimilarity matrix (MxM).
% For example: R = 20, seed = 343
% The entries in the Interactions matrix are 0 and 1. 
%
% Author: Maja Temerinac-Ott
% Date: Feb 2014
% E-Mail: temerina@frias.uni-freiburg.de
%Train by actively selecting from 80% of drugs
NUM_DRUGS = size(DrugSimilarity,1);
NUM_PROTEINS = size(ProteinSimilarity,1);
rand('state', seed);ind_train = randsample(1:NUM_DRUGS,round(0.8*NUM_DRUGS));
ind_train = sort(ind_train);
Y_true_train = Interactions(:,ind_train);
DrugSimilarity_training = DrugSimilarity(ind_train,ind_train);
[Y_queired_all, Y_likelihood_all,Az_all,Ax_all] = active_learning_KBMF_drugs(Y_true_train, DrugSimilarity_training,ProteinSimilarity,R,seed);

Y_queired_all_train = Y_queired_all;
Y_likelihood_all_train = Y_likelihood_all;

% Compute the test index
ind_help = zeros(NUM_DRUGS,1);
ind_help(ind_train)=1;
ind_test = find(ind_help==0);
Y_true_test = Interactions(:,ind_test);

numTest = length(ind_test);
F_computed = zeros(NUM_PROTEINS,numTest);
Y_likelihood_all_test = zeros(NUM_PROTEINS,numTest,size(Ax_all,3));

for num_runs = 1:size(Ax_all,3)
    for i = 1:numTest
        %find out what drugs have been selected for computing Az i.e. consider
        %the non zero entries of the first row of Y_queired_all
        Y_queried = Y_queired_all(:,:,num_runs);
        ind2 = find(Y_queried(1,:)~=0);
        Kz_test_single = DrugSimilarity(ind_test(i),ind_train(ind2));
        Az = Az_all{num_runs};
        Ax = Ax_all(:,:,num_runs);
        F = Kz_test_single*Az*Ax'*ProteinSimilarity;
        F_computed(:, i) = F;
    end
    Y_likelihood_all_test(:,:,num_runs) = F_computed;
end
