function [Y_queired_all,Y_predict_all] = active_learning_KBMF_rand(Interactions, DrugSimilarity,ProteinSimilarity,R,seed)
% Function to perform active learning on a protein-drugs interaction matrix.
% Random entries of the interaction matrix are picked for intialization.
%
% The parameters are the seed for the random initalization of the column and
% the subspace dimension R, as well as an Interactions matrix (NxM), a ProteinSimilarity matrix (NxN) and a DrugSimilarity matrix (MxM).
% For example: R = 20, seed = 343
% The entries in the Interactions matrix are 0 and 1. 
%
% Author: Maja Temerinac-Ott
% Date: Jan 2014
% E-Mail: temerina@frias.uni-freiburg.de
rdata = Interactions;
rdata(Interactions==0)=-1;
true_Interactions = rdata;

%Percent of interactions per batch
percent = 0.01;
batch_size = round(percent*length(rdata(:)));

Kz = DrugSimilarity;
Kx = ProteinSimilarity;
NUM_PROTEINS = size(ProteinSimilarity,1);
NUM_DRUGS = size(DrugSimilarity,1);
%Iterate through data

%Initialize the queried Labels
Y_queried = zeros(size(rdata));
%Pick random samples (no column explicitely)
rand('state', seed);rand_index = randsample(1:NUM_PROTEINS*NUM_DRUGS,NUM_DRUGS+NUM_PROTEINS);
[known_indx known_indz] = ind2sub(size(rdata),rand_index);

for i = 1:length(known_indx(:))
Y_queried(known_indx(i),known_indz(i)) = true_Interactions(known_indx(i),known_indz(i));
end

% Choose 1% of interactions as batch_size
experiments_left = length(rdata(:))-length(known_indx);
total_runs = round(experiments_left/batch_size)+1;
percent_of_experiments = zeros(total_runs,1) ;

Y_queired_all = zeros(size(Y_queried,1),size(Y_queried,2),total_runs);
Y_predict_all = zeros(size(Y_queried,1),size(Y_queried,2),total_runs);

for num_runs = 1:total_runs
%Generate Model for External Method
[Ax Az] = computeAs( Kx, Kz, Y_queried, R);
F = computeF(Ax,Az,Kx,Kz);
F_binary = computeF_binary(F,Y_queried);
numb_known_interactions = length(find(Y_queried(:)~=0));
percent_of_experiments(num_runs) = numb_known_interactions/length(Y_queried(:));
Y_queired_all(:,:,num_runs) = Y_queried;
Y_predict_all(:,:,num_runs) = F_binary;
%Pick Labels using some Active Learning Strategy
[known_indx,known_indz] = uncertainty_sampling(F,known_indx,known_indz,batch_size);
Y_queried = updateY_queried(known_indx,known_indz,true_Interactions);
display(['Percent of experiments completed: ',num2str(100*numb_known_interactions/length(Y_queried(:))) ]);
end

