function [feats] = calc_external_feats_new_maja(queried, predicted, truth)
% Function to compute features for lasso regression.
%
% For the queried and predicted values: -1: no interaction, 0:don' know,
% 1:interaction
% For the ground truth (Interactions.mat): 0:no interaction,1:interaction
%
% Author: Maja Temerinac-Ott
% Date: Jan 2014
% E-Mail: temerina@frias.uni-freiburg.de

nm = numel(truth);
feats = zeros(size(predicted,3)-1,15);

% batch (as a fraction)
feats(:,2) = (2:size(predicted,3))/size(predicted,3);
for i = 2:size(predicted,3)
    abs_queried = abs(queried(:,:,i));
    new_from_last_mask = abs(queried(:,:,i))-abs(queried(:,:,i-1));
    previous_frontier_size = sum(sum(new_from_last_mask));
    % prediction accuracy (as a fraction) on the test set
    feats(i-1,1) = computeEvaluationMeasureForAll(queried(:,:,i),predicted(:,:,i),truth);
    % predicted for queried experiments saved
    feats(i-1,3) = sum(sum(abs_queried.*(queried(:,:,i)-predicted(:,:,i))))/sum(sum(abs_queried));
    % average observed responsiveness across columns (normalized to 0..1)
    feats(i-1,4) = mean(sum(queried(:,:,i)==1,1)/size(predicted,1));
    % average observed responsiveness across rows (normalized to 0..1)
    feats(i-1,5) = mean(sum(queried(:,:,i)==1,2)/size(predicted,2));
    % average predicted responsiveness across columns (normalized to 0..1)
    feats(i-1,6) = mean(sum(predicted(:,:,i)==1,1)/size(predicted,1));
    % average predicted responsiveness across rows (normalized to 0..1)
    feats(i-1,7) = mean(sum(predicted(:,:,i)==1,2)/size(predicted,2));
    % average difference in predictions from last (normalized to 0..1)
    feats(i-1,8) = sum(sum(predicted(:,:,i).*predicted(:,:,i-1)))/nm;
    % average difference in predictions from last for previous frontier (normalized to 0..1)
    feats(i-1,9) = sum(sum(new_from_last_mask.*(predicted(:,:,i).*predicted(:,:,i-1))))/previous_frontier_size ;
    % fraction of previous frontier observed as responsive
    feats(i-1,10) = sum(sum(new_from_last_mask.*(queried(:,:,i)==1)))/previous_frontier_size;
    % min condition coverage
    feats(i-1,10) = min(sum(abs_queried,1))/size(predicted,1);
    % min target coverage
    feats(i-1,11) = min(sum(abs_queried,2))/size(predicted,2);
    % average condition coverage
    feats(i-1,12) = mean(sum(abs_queried,1))/size(predicted,1);
    % average target coverage
    feats(i-1,13) = mean(sum(abs_queried,2))/size(predicted,2);
    % max condition coverage
    feats(i-1,14) = max(sum(abs_queried,1))/size(predicted,1);
    % max target coverage
    feats(i-1,15) = max(sum(abs_queried,2))/size(predicted,2);
end


end

