% Computes the CrossValidation for clustered drugs, where 80% of each drug
% cluster are taken for training and the ramaining 20% for testing

% Basic assumption: It is easier to predict for the remaining if similar
% drugs have been used for training
clear all
close all
%Load data clustering
%filename = 'NuclearReceptor';
%filename = 'GPCR';
%filename = 'IonChannel';
filename = 'Enzyme';
curr_path = which('figure3a.m');
NrDataPath = [curr_path(1:end-15),'PrimaryData\ProteinDrugsDatabase\',filename,'\'];
load([NrDataPath,'Interactions.mat'],'Interactions');
% No interaction is weighted with -1
Interactions(Interactions==0)=-1;
load([NrDataPath,'ProteinSimilarity.mat']);
load([NrDataPath,'DrugSimilarity.mat']);
load([filename,'ClusteringOfDrugs.mat']);
%Select clustering with lowest AIC value
[mval,mind] = max(AIC);
cind = Index(mind,:);
k = max(cind);

numDrugs = size(DrugSimilarity,1);
numRuns = 25;
seed =  randsample(1000,numRuns);
AUC = zeros(numRuns,1);
numTraining = round(0.8*numDrugs);
numTest = numDrugs - numTraining-1;
TestData = zeros(numRuns,numTest);
for iter = 1:numRuns
% Select 80% from each cluster for training and 20% for testing

indTraining = zeros(numTraining,1);

count = 1;
for i = 1:k    
    indCluster = find(cind==i);rand('state', seed(iter));
    sampleCluster = randsample(indCluster,round(0.8*length(indCluster)));
    indTraining(count:count+length(sampleCluster)-1) = sampleCluster;
    count = length(sampleCluster)+count;
end

helpInd = zeros(numDrugs,1);
helpInd(indTraining) = 1;
indTest = find(helpInd==0);
TestData(iter,:)=indTest(1:numTest);
%Now use the training drugs to compute Ad and At and predict on the test
%drugs
R = 20; %Parameter for the dimension of projection

train_Set_drugs = DrugSimilarity(indTraining,indTraining,:);
train_Set_interactions = Interactions(:,indTraining);
%Train the paramters
state = kbmf_classification_train(ProteinSimilarity, train_Set_drugs, train_Set_interactions , R);
Ax = state.Ax.mean;
Az = state.Az.mean;

Fhelp = zeros(size(ProteinSimilarity,1),length(indTest));
Ghelp = Fhelp;
for i = 1:length(indTest)
      Kz_test_single = DrugSimilarity(indTest(i),indTraining);
      % Predicted Likelihood for each drug
      Fhelp(:,i) = Kz_test_single*Az*Ax'*ProteinSimilarity; 
      % True label
      Ghelp(:,i) = Interactions(:,indTest(i));
end
Ghelp(Ghelp==-1)=0;         
AUC(iter) = computeEvaluationMeasureAUCdrugs_holdout(Fhelp,Ghelp);
end