function val = compute_AUC(comp_likelihoods,labels)
%Computes the area under the ROC curve given a vector of computed
%likelihoods and a vector of true labels. The label of a positive example
%is 1 and of a negative example is 0.
%Author: Maja Temerinac-Ott
%e-mail: temerina@frias.uni-freiburg.de
%Date: 4.6.2013

ind = find(labels==1);
likelihood_pos = comp_likelihoods(ind);
ind2 = find(labels==0);
likelihood_neg = comp_likelihoods(ind2);
%List of sorted likelihoods
likelihoods = [likelihood_pos;likelihood_neg];
%Number of positive labels
nb_pos = sum(labels);

temp = sort(likelihoods, 'descend');
nb_total = max(size(temp));
nb_neg = nb_total - nb_pos;
prob_true_pos = zeros(1,nb_pos + nb_neg+1);
prob_false_pos = zeros(1,nb_pos + nb_neg+1);

for j=1:max(size(temp))	% for all thresholds
		thr=temp(j);
		prob_true_pos(j+1) = sum(likelihoods(1:nb_pos) >= thr) / nb_pos;
		prob_false_pos(j+1) = sum(likelihoods((nb_pos+1):end) >= thr) / nb_neg;
end

val = sum((prob_false_pos(2:end)-prob_false_pos(1:end-1)).*...
                    (prob_true_pos(2:end)+prob_true_pos(1:end-1))/2);
% %Plot ROC
% figure;plot(prob_false_pos,prob_true_pos)
% prob_false_pos
% prob_true_pos
