function figure3a
% Generates Figure 3 (a)
% from the paper "Deciing when to stop: Efficient experimentation to learn to predict drug-target interactions", Maja Temerinac-Ott, Armaghan W Naik and Robert F Murphy
%
% Script for predicting the accuracy of KBMF with active learning using
% regression paramters computed by lasso regression on simulated data
%
% Author: Maja Temerinac-Ott
% Date: Jan 2015
% E-Mail: temerina@frias.uni-freiburg.de

% 07272105 icaoberg Updated code to be compatible with OSX/Linux

pathToSimulatedData = [pwd, filesep, ...
    'IntermediateData' filesep 'SimulatedData' filesep ];
if ~exist( pathToSimulatedData )
    mkdir( pathToSimulatedData );
end

fpath = [pwd, filesep,'IntermediateData' filesep 'RegressionParams' filesep ...
    'regressionParams.mat'];
% Use Simulation to compute the regression parameters
if exist( fpath )
    load( fpath )
else
    if exist(pathToSimulatedData)
        [raw_fit,bestlambda] = computeRegressionParamters(pathToSimulatedData);
    else
        mkdir(pathToSimulatedData)
        display('Generating new simulation data')
        performSimulation(pathToSimulatedData)
        [raw_fit,bestlambda] = computeRegressionParamters(pathToSimulatedData);
    end
end

% Predict accuracy on unseen data using the precomputed regression
% parameters
IntermediatePath = [pwd, filesep,'IntermediateData' filesep 'NuclearReceptor' filesep];
if ~exist( IntermediatePath )
    mkdir( IntermediatePath )
end

PrimaryPath = [pwd, filesep,'PrimaryData' filesep 'ProteinDrugsDatabase' filesep 'NuclearReceptor' filesep];
if ~exist( PrimaryPath )
    mkdir( PrimaryPath )
end
load([IntermediatePath,'Y_queried_for_each_run_col_initalization_R_20_seed_343.mat']);
load([IntermediatePath,'Y_predicted_for_each_run_col_initalization_R_20_seed_343.mat']);
load([PrimaryPath,'Interactions.mat']);
Y_true = Interactions;
Y_true(Y_true==0)=-1;
predictedAccuracy = predictAccuracy(raw_fit,bestlambda,Y_queired_all, Y_predict_all);

percentageExperiments = computePercentageCompleted(Y_queired_all);
trueAccuracy = computeEvaluationMeasure(Y_queired_all,Y_predict_all,Y_true);

try
    figure;title('Predicted Accuracy for Nuclear Receptor (red)')
    hold on
    %For the very first prediction, we cannot predict the accuracy since there are no statistics available yet
    plot(percentageExperiments(2:end), trueAccuracy(2:end), 'k')
    plot(percentageExperiments(2:end), predictedAccuracy, 'r')
    hold off
    xlabel('Percent of Experiments for Training')
    ylabel('Accuracy on Remaining Experiments')
    axis([0 1 0.69 1.01])
    saveas(gcf, 'figure3a.jpg' )
    close
catch err
    warning( 'Unable to open figure. Skipping Figura 3a.' )
    getReport( err )
end
