function figure4()
% Generates Figure 4
% from the paper "Deciding when to stop: Efficient experimentation to learn to predict drug-target interactions", Maja Temerinac-Ott, Armaghan W Naik and Robert F Murphy
%
% Script for measuring on simulated data how often the predicted accuracy
% is a lower bound for the true accuracy
%
% Author: Maja Temerinac-Ott
% Date: Jan 2015
% E-Mail: temerina@frias.uni-freiburg.de

% 07282105 icaoberg Updated code to be compatible with OSX/Linux

% Load the simulation data
pathToSimulatedData = [pwd, filesep,'IntermediateData' filesep ...
    'SimulatedData' filesep];
pathToIntermediateData = [pwd, filesep,'IntermediateData' filesep ...
    'CrossValidation11Repeats_s2' filesep];

if exist(pathToSimulatedData)
    display('Using existing simulation data')
else
    mkdir(pathToSimulatedData)
    display('Generating new simulation data')
    performSimulation(pathToSimulatedData)
end

if exist(pathToIntermediateData)
    ComputeProbabilityTrueGreaterPredicted(pathToIntermediateData);
else
    %Select training and test data for CrossValidation
    %need first to know how many data sets are available
    numData = findNumDataSets(pathToSimulatedData);
    numFolds = 11;
    numRepeats = 11;
    D_assign = Generate_CrossvalidationDataPartition(numData,numFolds,numRepeats);
    % save('DFoldAssignment.mat','D_assign')
    
    greater_or_equal_predicted_accuracy = zeros(100,1);
    less_predicted_accuracy = zeros(100,1);
    
    for currentRepeat = 1:numRepeats
        %currentRepeat = 1;
        Fold_assign = D_assign(currentRepeat,:);
        for currentFold=1:numFolds
            %    currentFold=1;
            nameRegressstionparameters = [ 'FitForRepeat', ...
                num2str(currentRepeat),'Fold',num2str(currentFold),'.mat'];
            if(exist(nameRegressstionparameters,'file'))
                load(nameRegressstionparameters)
            else
                [raw_fit,bestlambda] = computeRegressionParamtersOnTraining(pathToSimulatedData,currentFold,Fold_assign);
                save(nameRegressstionparameters,'raw_fit','bestlambda')
            end
            
            % Use Simulation to compute the regression parameters
            
            %For each of the simulated matrix traces in the test set check whether the predicted
            %accuracy is greater or equal to the true accuracy
            s = what(pathToSimulatedData);
            
            numTrace = 1;
            count = 1;
            namePredictionsPerFold = ['PredictVsTrueForRepeat',num2str(currentRepeat),'Fold',num2str(currentFold),'.mat'];
            numTest = length(find(Fold_assign==currentFold));
            allPredicted = zeros(numTest,96);
            allTrue = zeros(numTest,96);
            % figure;
            % hold on;
            for z = 1:numel(s.mat)
                if strcmp(s.mat{z}(1:11),'Predicted_u')
                    if(Fold_assign(numTrace)==currentFold)
                        predicted = load([s.path,filesep,s.mat{z}]);
                        queried = load([s.path,filesep,'Queried' s.mat{z}(10:end)]);
                        interactions = load([s.path,filesep,'Interactions' s.mat{z}(10:end)]);
                        predictedAccuracy = predictAccuracy(raw_fit,bestlambda,queried.queried, predicted.predicted);
                        trueAccuracy = computeEvaluationMeasure(queried.queried, predicted.predicted,interactions.interactions);
                        percentageQueried = computePercentageCompleted(queried.queried);
                        trueAccuracy = trueAccuracy(2:end);
                        allPredicted(count,:)=predictedAccuracy;
                        allTrue(count,:)=trueAccuracy;
                        save(namePredictionsPerFold,'allPredicted','allTrue');
                        %plot(predictedAccuracy(1:end-1),trueAccuracy(1:end-1),'.');
                        for ind = 1:length(predictedAccuracy)
                            indArray = max(1,round(predictedAccuracy(ind)*100));
                            if trueAccuracy(ind)>=predictedAccuracy(ind)
                                greater_or_equal_predicted_accuracy(indArray) = greater_or_equal_predicted_accuracy(indArray)+1;
                            else
                                less_predicted_accuracy(indArray) = less_predicted_accuracy(indArray)+1;
                            end
                        end
                        count = count+1;
                    end
                    numTrace = numTrace+1;
                end
            end
            
            
            %xlabel('predicted Accuracy');ylabel('true Accuracy')
            %hold off
            
        end
    end
    
    total_samples = greater_or_equal_predicted_accuracy+less_predicted_accuracy;
    total_samples_help = total_samples;
    total_samples_help(total_samples==0)=1;
    percent_above_prediction = greater_or_equal_predicted_accuracy./total_samples_help;
    xq = 1:100;
    v = percent_above_prediction(total_samples~=0);
    ind = find(total_samples~=0);
    x = ind;
    vq1 = interp1(x,v,xq);
    
    try
        figure;
        plot(xq/100,vq1)
        xlabel('Predicted Accuracy on Remaining Experiments');ylabel('Probability for True Accuracy >= Predicted Accuracy')
        axis([0 1 0 1.01])
        hold on
        plot([xq(90)/100,xq(90)/100],[0,vq1(90)],'r')
        a = annotation('textarrow', [.65 .82], [.3 .3], 'String' , 'Threshold=0.9' );
        hold off
        saveas( gcf, 'figure4a.jpg' )
        close
        figure;
        plot(0.01:0.01:1,percent_above_prediction);
        saveas( gcf, 'figure4b.jpg' )
        close
    catch err
        warning( 'Unable to open figure. Skipping Figura 4.' )
        getReport( err )
    end
end