function [rdata, drug_kernel, protein_kernel] = generate_case(NUM_PROTEINS, NUM_DRUGS, FRACTION_RESPONSIVE, FRACTION_UNIQUE, FRACTION_UNINFORMATIVE)
% Generates a random interaction matrix given a set of parameters
% derived parameters

% number of underlying proteins (before replication)
% there have to be at least one underlying protein and one underlying drug
nunderlying_proteins = round( NUM_PROTEINS * FRACTION_UNIQUE);
nunderlying_drugs = round( NUM_DRUGS * FRACTION_UNIQUE);

response_data = zeros(nunderlying_proteins, nunderlying_drugs);

% compute the underlying ("no-drug") phenotypes
% for the 2 phenotype case, "no effect" is 0
unperturbed = zeros(nunderlying_proteins,1);

% determine the dependence of the underlying proteins to the drugs

responses_per_drug = repmat([round(FRACTION_RESPONSIVE*nunderlying_proteins)], 1, nunderlying_drugs);
%min(poissrnd(FRACTION_RESPONSIVE*nunderlying_proteins, 1, nunderlying_drugs), nunderlying_proteins);

% for each drug, compute the response patterns
for d = 1:nunderlying_drugs
    % choose a random permutation of the proteins...
    sigma = randperm(nunderlying_proteins);
    % ...of size indicated by the poisson response
    idxn = sigma(1:responses_per_drug(d));
    % ...at positions given by the permutation chosen to differing
    % phenotypes
    response_data(idxn,d) = 1;
end

%% complete the full data

% replicate proteins chosen u.a.r. from the underlying set
%replicated_protein_idxn = randint(NUM_PROTEINS - nunderlying_proteins,1,[1 nunderlying_proteins]);
replicated_protein_idxn = randi(nunderlying_proteins,NUM_PROTEINS - nunderlying_proteins,1);
% replicate drugs chosen u.a.r. from the underlying set
%replicated_drug_idxn = randint(NUM_DRUGS - nunderlying_drugs,1,[1 nunderlying_drugs]);
replicated_drug_idxn = randi(nunderlying_drugs,NUM_DRUGS - nunderlying_drugs,1);

rdata = zeros(NUM_PROTEINS, NUM_DRUGS);
rdata(1:nunderlying_proteins,1:nunderlying_drugs) = response_data;

for i = 1:(NUM_DRUGS-nunderlying_drugs)
    rdata(1:nunderlying_proteins, i+nunderlying_drugs) = rdata(1:nunderlying_proteins,replicated_drug_idxn(i));
end

for i = 1:(NUM_PROTEINS - nunderlying_proteins)
    rdata(i+nunderlying_proteins,:) = rdata(replicated_protein_idxn(i),:);
end


% now we need to make kernels for these data
corruption_rdata = zeros(size(rdata));
cxs = randperm(numel(rdata));
corruption_rdata(cxs(1:round(FRACTION_UNINFORMATIVE*length(cxs)))) = 1;

drug_kernel = squareform(exp(-pdist(corruption_rdata)));
drug_kernel = drug_kernel + eye(length(drug_kernel));

protein_kernel = squareform(exp(-pdist(corruption_rdata')));
protein_kernel = protein_kernel + eye(length(protein_kernel));
