% Mehmet Gonen (mehmet.gonen@aalto.fi)
% Helsinki Institute for Information Technology HIIT
% Department of Information and Computer Science
% Aalto University School of Science

function state = kbmf_regression_train(Kx, Kz, Y, R, varargin)
    addpath('kbmf2k');
    addpath('kbmf1mkl1k');
    addpath('kbmf1k1mkl');
    addpath('kbmf2mkl');
    Px = size(Kx, 3);
    Pz = size(Kz, 3);
    is_supervised = all(~isnan(Y(:)));

    parameters.alpha_lambda = 1;
    parameters.beta_lambda = 1;
    if Px > 1 || Pz > 1
        parameters.alpha_eta = 1;
        parameters.beta_eta = 1;
    end
    parameters.iteration = 200;
    parameters.progress = 1;
    parameters.R = R;
    parameters.seed = 1606;
    parameters.sigmag = 0.1;
    if Px > 1 || Pz > 1
        parameters.sigmah = 0.1;
    end
    parameters.sigmay = 1.0;

    if is_supervised == 1
        if Px == 1 && Pz == 1
            train_function = @kbmf2k_supervised_regression_variational_train_with_bound;
            test_function = @kbmf2k_supervised_regression_variational_test;
        elseif Px > 1 && Pz == 1
            train_function = @kbmf1mkl1k_supervised_regression_variational_train;
            test_function = @kbmf1mkl1k_supervised_regression_variational_test;
        elseif Px == 1 && Pz > 1
            train_function = @kbmf1k1mkl_supervised_regression_variational_train;
            test_function = @kbmf1k1mkl_supervised_regression_variational_train;
        elseif Px > 1 && Pz > 1
            train_function = @kbmf2mkl_supervised_regression_variational_train;
            test_function = @kbmf2mkl_supervised_regression_variational_test;
        end
    else
        if Px == 1 && Pz == 1
            train_function = @kbmf2k_semisupervised_regression_variational_train;
            test_function = @kbmf2k_semisupervised_regression_variational_test;
        elseif Px > 1 && Pz == 1
            train_function = @kbmf1mkl1k_semisupervised_regression_variational_train;
            test_function = @kbmf1mkl1k_semisupervised_regression_variational_test;
        elseif Px == 1 && Pz > 1
            train_function = @kbmf1k1mkl_semisupervised_regression_variational_train;
            test_function = @kbmf1k1mkl_semisupervised_regression_variational_test;
        elseif Px > 1 && Pz > 1
            train_function = @kbmf2mkl_semisupervised_regression_variational_train;
            test_function = @kbmf2mkl_semisupervised_regression_variational_test;
        end
    end

    for i = 1:2:nargin - 4
        parameters.(varargin{i}) = varargin{i + 1};
    end
    
    parameters.train_function = train_function;
    parameters.test_function = test_function;

    state = train_function(Kx, Kz, Y, parameters);
end