% Script to perform random learning on a protein-drugs interaction matrix.
% A random column in the interaction matrix along with one random sample
% from each row are used for initialization. The samples for the next batch
% are chosen randomly
%
% The parameters are the seed for the random initalization of the column,
% a random number to generate a random sampling of the data and 
% the subspace dimension R, as well as an Interactions matrix (NxM), a ProteinSimilarity matrix (NxN) and a DrugSimilarity matrix (MxM).
% For example: R = 20, seed = 343, RandomRun=1
% The entries in the Interactions matrix are 0 and 1. 
%
% Author: Maja Temerinac-Ott
% Date: Jan 2014
% E-Mail: temerina@frias.uni-freiburg.de

function [Y_queired_all,Y_predict_all] = random_learning_KBMF_column(Interactions, DrugSimilarity,ProteinSimilarity,R,seed,RandomRun)

rdata = Interactions;
rdata(Interactions==0)=-1;
true_Interactions = rdata;

%Percent of interactions per batch
percent = 0.01;
batch_size = round(percent*length(rdata(:)));

Kz = DrugSimilarity;
Kx = ProteinSimilarity;
NUM_PROTEINS = size(ProteinSimilarity,1);
NUM_DRUGS = size(DrugSimilarity,1);
%Iterate through data

%Initialize the queried Labels
Y_queried = zeros(size(rdata));

%Pick drug
rand('state', seed);drug_column = round(NUM_DRUGS*rand(1,1));
rand('state', seed);rand_index = randsample(1:NUM_PROTEINS,NUM_DRUGS,'true');

known_indx = [1:NUM_PROTEINS,rand_index];
known_indz = [drug_column*ones(NUM_PROTEINS,1)',1:NUM_DRUGS];


for i = 1:length(known_indx(:))
Y_queried(known_indx(i),known_indz(i)) = true_Interactions(known_indx(i),known_indz(i));
end
index_experiments_left = find(Y_queried==0);
% Choose 1% of interactions as batch_size
experiments_left = length(rdata(:))-length(known_indx);
total_runs = round(experiments_left/batch_size)+1;

percent_of_experiments = zeros(total_runs,1) ;

Y_queired_all = zeros(size(Y_queried,1),size(Y_queried,2),total_runs);
Y_predict_all = zeros(size(Y_queried,1),size(Y_queried,2),total_runs);

%Now we must generate random numbers from the left indices only
rand('state', RandomRun);rand_index = randsample(index_experiments_left,length(index_experiments_left));
count=1;
for num_runs = 1:total_runs
%Generate Model for External Method
[Ax Az] = computeAs( Kx, Kz, Y_queried, R);
F = computeF(Ax,Az,Kx,Kz);
F_binary = computeF_binary(F,Y_queried);
numb_known_interactions = length(find(Y_queried(:)~=0));
percent_of_experiments(num_runs) = numb_known_interactions/length(Y_queried(:));
Y_queired_all(:,:,num_runs) = Y_queried;
Y_predict_all(:,:,num_runs) = F_binary;
%Pick Labels using Random Strategy
ind = rand_index(count:min(count+batch_size-1,length(rand_index)));
count =  count+batch_size;
[I,J] = ind2sub(size(F),ind(1:min(length(ind),batch_size)));
%add the new proteins/drugs to the index
known_indx = [known_indx,I'];
known_indz = [known_indz,J'];
Y_queried = updateY_queried(known_indx,known_indz,true_Interactions);
display(['Percent of experiments completed: ',num2str(100*numb_known_interactions/length(Y_queried(:))) ]);

end

