function run( option )
% Main script from the paper
% "Deciding when to stop: Efficient experimentation to learn to predict drug-target interactions", Maja Temerinac-Ott, Armaghan W Naik and Robert F Murphy
%
% Author: Maja Temerinac-Ott
% Date: Jan 2015
% E-Mail: temerina@frias.uni-freiburg.de

if nargin == 0
    option = 'all';
else
    option = 'intermediate_results';
end

addpath( pwd );
addpath( 'glmnet_matlab' );
addpath( genpath( 'modifiedKBMFcode' ) );

if ismac() || isunix()
    if strcmpi( option, 'all' )
        disp( 'Download raw data. Please wait...')
        url='http://murphylab.web.cmu.edu/software/2015_BMC_bioinformatics/BMC_active_primary_data.tgz';
        filename = 'BMC_active_primary_data.tgz';
        urlwrite( url, filename )
        !tar -xvf BMC_active_primary_data.tgz
    elseif strcmpi( option, 'intermediate_results' )
        disp( 'Download raw data and intermediate results. Please wait...')
        url='http://murphylab.web.cmu.edu/software/2015_BMC_bioinformatics/BMC_active_primary_data.tgz';
        filename = 'BMC_active_primary_data.tgz';
        urlwrite( url, filename )
        !tar -xvf BMC_active_primary_data.tgz
        
        url = 'http://murphylab.web.cmu.edu/software/2015_BMC_bioinformatics/';
        files={'BMC_active_intermediate_data.tar.aa';
            'BMC_active_intermediate_data.tar.ab';
            'BMC_active_intermediate_data.tar.ac';
            'BMC_active_intermediate_data.tar.ad';
            'BMC_active_intermediate_data.tar.ae';
            'BMC_active_intermediate_data.tar.af';
            'BMC_active_intermediate_data.tar.ag';
            'BMC_active_intermediate_data.tar.ah';
            'BMC_active_intermediate_data.tar.ai';
            'BMC_active_intermediate_data.tar.aj';
            'BMC_active_intermediate_data.tar.ak';
            'BMC_active_intermediate_data.tar.al';
            'BMC_active_intermediate_data.tar.am';
            'BMC_active_intermediate_data.tar.an';
            'BMC_active_intermediate_data.tar.ao';
            'BMC_active_intermediate_data.tar.ap';
            'BMC_active_intermediate_data.tar.aq';
            'BMC_active_intermediate_data.tar.ar';
            'BMC_active_intermediate_data.tar.as';
            'BMC_active_intermediate_data.tar.at';
            'BMC_active_intermediate_data.tar.au';
            'BMC_active_intermediate_data.tar.av';
            'BMC_active_intermediate_data.tar.aw';
            'BMC_active_intermediate_data.tar.ax';
            'BMC_active_intermediate_data.tar.ay';
            'BMC_active_intermediate_data.tar.az';
            'BMC_active_intermediate_data.tar.ba';
            'BMC_active_intermediate_data.tar.bb';
            'BMC_active_intermediate_data.tar.bc';
            'BMC_active_intermediate_data.tar.bd';
            'BMC_active_intermediate_data.tar.be';
            'BMC_active_intermediate_data.tar.bf';
            'BMC_active_intermediate_data.tar.bg';
            'BMC_active_intermediate_data.tar.bh';
            'BMC_active_intermediate_data.tar.bi';
            'BMC_active_intermediate_data.tar.bj';
            'BMC_active_intermediate_data.tar.bk';
            'BMC_active_intermediate_data.tar.bl';
            'BMC_active_intermediate_data.tar.bm';
            'BMC_active_intermediate_data.tar.bn';
            'BMC_active_intermediate_data.tar.bo';
            'BMC_active_intermediate_data.tar.bp';
            'BMC_active_intermediate_data.tar.bq';
            'BMC_active_intermediate_data.tar.br';
            'BMC_active_intermediate_data.tar.bs';
            'BMC_active_intermediate_data.tar.bt';
            'BMC_active_intermediate_data.tar.bu';
            'BMC_active_intermediate_data.tar.bv';
            'BMC_active_intermediate_data.tar.bw';
            'BMC_active_intermediate_data.tar.bx';
            'BMC_active_intermediate_data.tar.by';
            'BMC_active_intermediate_data.tar.bz';
            'BMC_active_intermediate_data.tar.ca';
            'BMC_active_intermediate_data.tar.cb';
            'BMC_active_intermediate_data.tar.cc';
            'BMC_active_intermediate_data.tar.cd';
            'BMC_active_intermediate_data.tar.ce';
            'BMC_active_intermediate_data.tar.cf';
            'BMC_active_intermediate_data.tar.cg';
            'BMC_active_intermediate_data.tar.ch';
            'BMC_active_intermediate_data.tar.ci'};
        
        disp( 'Downloading intermediate results' )
        for index=1:1:length(files)
            disp( ['Downloading file ' num2str(index) ' of ' ...
                num2str(length(files)) ] );
            filename = files{index};
            urlwrite( [url filename], filename )
        end
        
        disp( 'Concatenating files. Please wait...' );
        !cat BMC_active_intermediate_data.tar.* > BMC_active_intermediate_data.tar
        
        disp( 'Extracting files. Please wait...' );
        !tar -xvf BMC_active_intermediate_data.tar
        
    else
        error('Unknown option.')
    end
elseif ispc()
    warning('This source code has not been tested in any Windows flavor.')
    return
else
    error( 'Unknown OS or unsupported OS.' );
end

disp( 'Generating figures' );
generate_figures

disp( 'Generating tables' );
generate_tables

clear all
close all