function table1()
% Generates Table 1
% from the paper "Deciding when to stop: Efficient experimentation to learn to predict drug-target interactions", Maja Temerinac-Ott, Armaghan W Naik and Robert F Murphy
%
% Author: Maja Temerinac-Ott
% Date: Jan 2015
% E-Mail: temerina@frias.uni-freiburg.de

% Average AUC on hold out data and percentage of experiments after applying our stopping rule. The average AUC obtained on
% held out data using 80% of the data for training Goenen 2012 is compared with the average AUC obtained by training with only the listed
% percentage of experiments obtained by applying the stopping rule. The percentage of experiments can be halved by using the proposed
% stopping rule.

% 1. We set a threshold for predicted accuracy after which to stop
% 2. We report the percentage of training data after stopping
% 3. We report the AUC value and the percentage of experiments performed after stopping.

clear all
close all
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Choose the dataset
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

mydatasets = struct('name',{},'mean_percentTraining',{},'std_percentTraining',{},'mean_AUC',{},'std_AUC',{});
mydatasets(1).name = ['NuclearReceptor' filesep];
mydatasets(2).name = ['GPCR' filesep];
mydatasets(3).name = ['IonChannel' filesep];
mydatasets(4).name = ['Enzyme' filesep];
curr_path = which('table1.m');
fname = [pwd, filesep, 'IntermediateData', filesep, ...
    'RegressionParams', filesep, 'mydatasets.mat'];

if(~exist(fname))
    for i = 1:4
    [mean_percentTraining,std_percentTraining,mean_AUC,std_AUC] = ApplyStoppingRuleInCrossValidation(mydatasets(i).name);
    mydatasets(i).mean_percentTraining = mean_percentTraining;
    mydatasets(i).std_percentTraining = std_percentTraining;
    mydatasets(i).mean_AUC = mean_AUC;
    mydatasets(i).std_AUC = std_AUC;
    end
    save(fname,'mydatasets');
else
    load(fname)
end

Goenen_AUC = [82.4 85.7 79.9 83.2];

fileID = fopen( 'table1.txt', 'w' );
fprintf( fileID, '%s\n', 'Dataset        Goenen results| With stopping rule' );
fprintf( fileID, '%s\n', '               AUC (%)       | AUC (%)| experiments (%)' );

for i=1:length(mydatasets)
str = mydatasets(i).name;
str = str(1:end-1);
parameters = [Goenen_AUC(i), 100*mydatasets(i).mean_AUC, 100*mydatasets(i).mean_percentTraining];
  for j=1:length( parameters )
    str = [ str ' ' num2str(parameters(j),'%6.1f') ];
  end
  fprintf( fileID, '%s\n', str );

end
fclose(fileID);
