function table2()
% Generates Table 2
% from the paper "Deciding when to stop: Efficient experimentation to learn to predict drug-target interactions", Maja Temerinac-Ott, Armaghan W Naik and Robert F Murphy
%
% Author: Maja Temerinac-Ott
% Date: Jan 2015
% E-Mail: temerina@frias.uni-freiburg.de.

%Average difference between the BST point and the stopping point chosen by various stopping rules, over all evaluation data
%sets. OU=Overall Average Uncertainty, MEE=Minimum Expected Error PA=Predicted Accuracy. The value in the brackets denotes the
%threshold. The smaller the difference ave value is, the better the stopping criterion is.
curr_path = which('table2.m');
IntermediateDataPathNr = [curr_path(1:end-17),'IntermediateData' filesep ...
    'StoppingRuleBenchmark' filesep ];

if(~exist(IntermediateDataPathNr))
    mkdir('IntermediateDataPathNr')
    computeBSTdrugs
    compute_simple_stopping_rule_drugs_uncertainty
    fname = [curr_path(1:end-17),'IntermediateData' filesep ...
        'RegressionParams', filesep, 'regressionParams.mat'];
    if exist(fname)
        load(fname)
    else
        pathToSimulatedData = [curr_path(1:end-17),'IntermediateData', ...
            filesep, 'SimulationResults' filesep];
        if exist(pathToSimulatedData)
            [raw_fit,bestlambda] = computeRegressionParamters(pathToSimulatedData);
        else
        mkdir(pathToSimulatedData)
        display('Generating new simulation data')
        performSimulation(pathToSimulatedData)
        end
    end
    compute_my_stopping_rule_drugs(bestlambda,raw_fit)
    compute_adapted_stopping_rule_drugs_uncertainty_EE
    compute_adapted_stopping_rule_drugs_uncertainty
    movefile('*.mat',[curr_path(1:end-17),'IntermediateData', ...
        filesep 'StoppingRuleBenchmark'])
else
    s=what(IntermediateDataPathNr); 
    matfiles=s.mat;
    for a=1:numel(matfiles)
        load([IntermediateDataPathNr,char(matfiles(a))])
    end 
end



numSeeds = 8;
RangeThr = [0.85 0.9 0.95];
averageDifferencePercent_PA = evaluateDifferenceToBSTmyMethod(RangeThr,numSeeds,IntermediateDataPathNr);
RangeThr = [0.12,0.09,0.06,0.03];
averageDifferencePercent_MEE = evaluateDifferenceToBST_MEE(RangeThr,numSeeds,IntermediateDataPathNr);
[averageDifferencePercent_MEEadapted,stdDifferencePercent_MEEadapted] = evaluateDifferenceToBST_MEE_adapted(numSeeds,IntermediateDataPathNr);
averageDifferencePercent_OU = evaluateDifferenceToBST_OU(RangeThr,numSeeds,IntermediateDataPathNr);
[averageDifferencePercent_OUadapted,stdDifferencePercent_OUadapted] = evaluateDifferenceToBST_OU_adapted(numSeeds,IntermediateDataPathNr);
fileID = fopen( 'table2.txt', 'w' );

fprintf( fileID, '%s\n', 'Methods    OU(0.12)   | OU(0.09)   | OU(0.06)    | OU(0.03)    | OU(adapted)     ' );
str = 'av_diff(%)';
for j=1:size(averageDifferencePercent_MEE,1)
    str = [ str '  ' num2str(100*averageDifferencePercent_OU(j,2),'%6.1f') '(' num2str(100*averageDifferencePercent_OU(j,3),'%6.1f') ')' ];
end
str = [ str '  ',  num2str(100*averageDifferencePercent_OUadapted,'%6.1f' ) '(' num2str(100*stdDifferencePercent_OUadapted,'%6.1f') ')' ];
fprintf( fileID, '%s\n', str );

fprintf( fileID, '%s\n', 'Methods    MEE(0.12)   | MEE(0.09)   | MEE(0.06)    | MEE(0.03)    | MEE(adapted)     ' );
str = 'av_diff(%)';
for j=1:size(averageDifferencePercent_MEE,1)
    str = [ str '  ' num2str(100*averageDifferencePercent_MEE(j,2),'%6.1f') '(' num2str(100*averageDifferencePercent_MEE(j,3),'%6.1f') ')' ];
end
str = [ str '  ',  num2str(100*averageDifferencePercent_MEEadapted,'%6.1f' ) '(' num2str(100*stdDifferencePercent_MEEadapted,'%6.1f') ')' ];
fprintf( fileID, '%s\n', str );

fprintf( fileID, '%s\n', 'Methods    PA(0.85)    | PA(0.9)     | PA(0.95)' );
str = 'av_diff(%)';
for j=1:size(averageDifferencePercent_PA,1)
    str = [ str '  ' num2str(100*averageDifferencePercent_PA(j,2),'%6.1f') '(' num2str(100*averageDifferencePercent_PA(j,3),'%6.1f') ')' ];
end
fprintf( fileID, '%s\n', str );

fclose(fileID);

